@@ -1,13 +1,17 @@
-/* ramdisk.c -- RAM disk block device implementation
- *
+/**
+ * @file rtems/ramdisk.h
+ * RAM disk block device implementation
+ */
+
+/*
  * Copyright (C) 2001 OKTET Ltd., St.-Petersburg, Russia
  * Author: Victor V. Vengerov <vvv@oktet.ru>
  *
- * @(#) $Id: ramdisk.h,v 1.1 2002/02/28 20:39:54 joel Exp $
+ * @(#) $Id: ramdisk.h,v 1.4 2005/02/17 07:24:46 ralf Exp $
  */
 
-#ifndef __RTEMS_LIBBLOCK_RAMDISK_H__
-#define __RTEMS_LIBBLOCK_RAMDISK_H__
+#ifndef _RTEMS_RAMDISK_H
+#define _RTEMS_RAMDISK_H
 
 #ifdef __cplusplus
 extern "C" {
@@ -31,7 +35,7 @@ typedef struct rtems_ramdisk_config {
  * The following is definitions for RAM disk configuration table
  */
 extern rtems_ramdisk_config rtems_ramdisk_configuration[];
-extern int rtems_ramdisk_configuration_size;
+extern size_t rtems_ramdisk_configuration_size;
 
 /* ramdisk_initialize --
  *     RAM disk driver initialization entry point.
