@@ -1,8 +1,12 @@
+/**
+ * @file rtems/capture-cli.h
+ */
+
 /*
   ------------------------------------------------------------------------
-  $Id: capture-cli.h,v 1.1 2002/05/15 16:35:56 joel Exp $
+  $Id: capture-cli.h,v 1.3 2004/12/02 18:20:50 ralf Exp $
   ------------------------------------------------------------------------
-  
+
   Copyright Objective Design Systems Pty Ltd, 2002
   All rights reserved Objective Design Systems Pty Ltd, 2002
   Chris Johns (ccj@acm.org)
@@ -14,7 +18,7 @@
   found in the file LICENSE in this distribution.
 
   This software with is provided ``as is'' and with NO WARRANTY.
-  
+
   ------------------------------------------------------------------------
 
   RTEMS Performance Monitoring and Measurement Framework.
@@ -33,7 +37,7 @@ extern "C" {
 
 #include <rtems/capture.h>
 
-/*
+/**
  * rtems_capture_cli_init
  *
  *  DESCRIPTION:
