@@ -10,11 +10,11 @@
  *  found in the file LICENSE in this distribution or at
  *  http://www.rtems.com/license/LICENSE.
  *
- *  $Id: mptables.h,v 1.7.6.1 2003/09/04 18:47:20 joel Exp $
+ *  $Id: mptables.h,v 1.9 2005/01/28 05:00:20 ralf Exp $
  */
 
-#ifndef __RTEMS_MPTABLES_h
-#define __RTEMS_MPTABLES_h
+#ifndef _RTEMS_MPTABLES_H
+#define _RTEMS_MPTABLES_H
 
 #ifdef __cplusplus
 extern "C" {
